@@ -1,5 +1,5 @@
 from bz2 import BZ2File
-from collections import namedtuple, UserDict, Sequence, Mapping
+from collections import namedtuple, UserDict, Sequence, Iterable, Mapping
 from email.mime.text import MIMEText
 from fuzzywuzzy import fuzz, process
 import inspect
@@ -66,10 +66,10 @@ class InvalidArgumentError(Exception):
 
 
 class FuzzyKeyDict(dict):
-    """Dictionary that tries to find similar keys if a key is missing and
-    returns their corresponding values. This could be useful as a word2index
-    mapping when working with embeddings: we could try mapping missing words to
-    a combination of existing words.
+    """Dictionary that will try to find similar keys if a key is missing and
+    return their corresponding values. This could be useful when working with
+    embeddings, where we could try mapping missing words to a combination of
+    existing words.
 
     Examples
     --------
@@ -82,33 +82,37 @@ class FuzzyKeyDict(dict):
     d['cowbell'] = 5
     d['baby cow'] = 6
 
-    # Keys and similarity scores are displayed because we're in verbose mode.
-    >>> res = d['house cat']
+    # Keys and similarity scores for the most similar keys.
+    >>> d.similar_keys('house cat')
     [('alley cat', 56), ('cat', 50), ('cowbell', 25)]
 
-    # Values correspond to d['alley cat'], d['cat'], d['cowbell'].
-    >>> res
+    # "house cat" not in dict so we get the values for the most similar keys.
+    >>> d['house cat']
     [2, 1, 5]
 
-    # "cat" is in our dict so no similarity scores are printed and output is
-    # an integer, not a list.
+    # "cat" is in dict so output is an integer rather than a list.
     >>> d['cat']
     1
     """
 
-    def __init__(self, limit=3, verbose=False):
+    def __init__(self, data=None, limit=3):
         """
         Parameters
         ----------
+        data: Iterable (optional)
+            Sequence of pairs, such as a dictionary or a list of tuples. If
+            provided, this will be used to populate the FuzzyKeyDict.
         limit: int
             Number of similar keys to find when trying to retrieve the value
             for a missing key.
-        verbose: bool
-            If True, this will print the similar keys and their similarity to
-            the queried key when trying to retrieve a missing key.
         """
+        if isinstance(data, Mapping):
+            for k, v in data.items():
+                self[k] = v
+        elif isinstance(data, Iterable):
+            for k, v in data:
+                self[k] = v
         self.limit = limit
-        self.verbose = verbose
 
     def __getitem__(self, key):
         """
@@ -124,10 +128,14 @@ class FuzzyKeyDict(dict):
         try:
             return super().__getitem__(key)
         except KeyError:
-            res = process.extract(key, self.keys(), limit=self.limit,
-                                  scorer=fuzz.ratio)
-            if self.verbose: print(res)
-            return [self[k] for k, v in res]
+            return [self[k] for k in self.similar_keys(key)]
+
+    def similar_keys(self, key, return_distances=False):
+        pairs = process.extract(key, self.keys(), limit=self.limit,
+                                scorer=fuzz.ratio)
+        if return_distances:
+            return pairs
+        return [p[0] for p in pairs]
 
 
 class LambdaDict(UserDict):
